# Graphene Modeling

This Python code models the electronic and optical properties of graphene and is accompanied by Jupyter notebooks.

**Install** with `pip install graphenemodeling`

**Test** your installation with the command `> graphenemodeling overview`. You should see the following image:

![](https://github.com/gholdman1/graphenemodeling/blob/master/notebooks/Graphene/images/overview.png)